import { Injectable } from '@nestjs/common';
import { TrpcService } from '@server/trpc/trpc.service';
import { TrainContentService } from './trainContent.service';
import { z, ZodType } from 'zod';
import { Prisma } from '@nice/common';

const TrainContentArgsSchema: ZodType<Prisma.TrainContentCreateArgs> = z.any();
const TrainContentUpdateArgsSchema: ZodType<Prisma.TrainContentUpdateArgs> =
  z.any();
const TrainContentFindManyArgsSchema: ZodType<Prisma.TrainContentFindManyArgs> =
  z.any();
const TrainContentFindFirstArgsSchema: ZodType<Prisma.TrainContentFindFirstArgs> =
  z.any();
@Injectable()
export class TrainContentRouter {
  constructor(
    private readonly trpc: TrpcService,
    private readonly trainContentService: TrainContentService,
  ) {}

  router = this.trpc.router({
    create: this.trpc.procedure
      .input(TrainContentArgsSchema)
      .mutation(async ({ input }) => {
        return this.trainContentService.create(input);
      }),
    update: this.trpc.procedure
      .input(TrainContentUpdateArgsSchema)
      .mutation(async ({ input }) => {
        return this.trainContentService.update(input);
      }),
    findMany: this.trpc.procedure
      .input(TrainContentFindManyArgsSchema)
      .query(async ({ input }) => {
        return this.trainContentService.findMany(input);
      }),
    findFirst: this.trpc.procedure
      .input(TrainContentFindFirstArgsSchema)
      .query(async ({ input }) => {
        return this.trainContentService.findFirst(input);
      }),
  });
}
