import { Button, Form, Input, InputNumber, Modal, Select } from "antd";
import { useSportPageContext } from "./sportPageProvider";
import { api, useTrainSituation } from "@nice/client";
import toast from "react-hot-toast";

export default function SportPageModal() {
    const { newScoreForm, isNewScoreModalVisible, handleNewScoreCancel, sportProjectList, staffs, staffsLoading } = useSportPageContext()
    const { createManyTrainSituation } = useTrainSituation()
    // 修改后的提交处理逻辑
    const handleNewScoreOk = async () => {
        const userId = newScoreForm.getFieldValue("user");
        if (!userId) {
            console.error("未选择人员");
            toast.error('请选择人员');
            return;
        }
        const userMsg = staffs?.find((item) => item.id === userId);
        const createTrainSituationMsg = sportProjectList?.filter(item=>item.deletedAt === null).map((item) => {
            const performanceValue = newScoreForm.getFieldValue(['sports', item.id, 'score']);
            if (!performanceValue) {
                console.error(`未输入 ${item.name} 的成绩`);
                toast.error(`请输入 ${item.name} 的成绩`);
                return;
            }
            // 处理数值类型转换
            const parsedPerformance = item.unit.includes('time')
                ? performanceValue // 保持时间字符串
                : Number(performanceValue);
            console.log('解析后的成绩:', parsedPerformance);
            return {
                staffId: userId,
                trainContentId: item.trainContentId,
                mustTrainTime: 0.0,
                alreadyTrainTime: 0.0,
                value: String(parsedPerformance),
                projectId: item.id,
                gender: userMsg?.sex ?? false, // 提供默认值
                age: userMsg?.age ?? 0,        // 提供默认值
                performance: parsedPerformance,
                personType: userMsg?.position?.categorize || "OFFICER",
                projectUnit: item.unit
            }
        });
        await createManyTrainSituation.mutateAsync([...createTrainSituationMsg])

        console.log("提交成功", createTrainSituationMsg);
        toast.success('成绩提交成功');
        handleNewScoreCancel();
    };
    return (
        <Modal
            title="添加考核成绩"
            onOk={newScoreForm.submit}
            open={isNewScoreModalVisible}
            onCancel={handleNewScoreCancel}
        >
            <Form
                form={newScoreForm}
                name="dynamic_form"
                onFinish={handleNewScoreOk}
                className="p-4 space-y-4"
            >
                <Form.Item
                    name="user"
                    label="选择人员"
                    rules={[{ required: true, message: '请选择人员!' }]}
                >
                    <Select
                        placeholder="选择人员"
                        options={staffsLoading ? [] : staffs?.map((item) => ({
                            label: item.username,
                            value: item.id
                        })) || []}
                    >
                    </Select>
                </Form.Item>
                {sportProjectList?.filter(item=>item.deletedAt === null).map((field) => (
                    <div key={field.id} className="flex w-full space-x-4">
                        <Form.Item
                            label={`${field.name}（${field.unit}）`}
                            name={['sports', field.id, 'score']}
                            rules={[{ required: true, message: '请输入成绩!' }]}
                        >
                            <Input className="w-full" placeholder="请输入成绩" />
                        </Form.Item>
                    </div>
                ))}
            </Form>
        </Modal>
    )
}

