import {
	createBrowserRouter,
	IndexRouteObject,
	Link,
	NonIndexRouteObject,
	useParams,
} from "react-router-dom";
import ErrorPage from "../app/error";
import LoginPage from "../app/login";
import HomePage from "../app/main/home/page";
import StaffMessage from "../app/main/staffpage/page";
import MainLayout from "../app/main/layout/MainLayout";
import DailyPage from "../app/main/daily/page";
import Dashboard from "../app/main/home/page";
import WeekPlanPage from "../app/main/plan/weekplan/page";
import AdminLayout from "../components/layout/admin/AdminLayout";
import { adminRoute } from "./admin-route";
import SportPage from "../app/main/sport/page";
import { SportPageProvider } from "../app/main/sport/sportPageProvider";
import PositionAssessmentPage from "../app/main/positionassessment/page";
import CommonAssessmentPage from "../app/main/commonassessment/page";
import MonthPlanPage from "../app/main/plan/monthplan/page";
interface CustomIndexRouteObject extends IndexRouteObject {
	name?: string;
	breadcrumb?: string;
}
interface CustomIndexRouteObject extends IndexRouteObject {
	name?: string;
	breadcrumb?: string;
}
export interface CustomNonIndexRouteObject extends NonIndexRouteObject {
	name?: string;
	children?: CustomRouteObject[];
	breadcrumb?: string;
	handle?: {
		crumb: (data?: any) => void;
	};
}
export type CustomRouteObject =
	| CustomIndexRouteObject
	| CustomNonIndexRouteObject;
export const routes: CustomRouteObject[] = [
	{
		path: "/",
		errorElement: <ErrorPage />,
		handle: {
			crumb() {
				return <Link to={"/"}>主页</Link>;
			},
		},

		children: [
			{
				element: <MainLayout></MainLayout>,
				children: [
					{
						index: true,
						element: <Dashboard></Dashboard>,
					},
					{
						path: "/staff",
						element: <StaffMessage></StaffMessage>,
					},
					{
						path: "/plan",
						children: [
							{
								path: "weekplan",
								element: <WeekPlanPage></WeekPlanPage>
							},
							{
								path: "monthplan",
								element: <MonthPlanPage></MonthPlanPage>
							}
						]
					},
					{
						path: "/daily",
						element: <DailyPage></DailyPage>
					},
					{
						path: "/assessment",
						children: [
							{
								path: "positionassessment",
								element: <PositionAssessmentPage></PositionAssessmentPage>
							},
							{
								path: "commonassessment",
								element: <CommonAssessmentPage></CommonAssessmentPage>
							},
							{
								path: "sportsassessment",
								element: <SportPageProvider>
									<SportPage></SportPage>
								</SportPageProvider>
							}
						]
					},
					{
						path: "/admin",
						element: <AdminLayout></AdminLayout>,
						children: adminRoute.children,
					}
				],
			},
		],
	},

	{
		path: "/login",
		breadcrumb: "登录",
		element: <LoginPage></LoginPage>,
	},
];

export const router = createBrowserRouter(routes);
